==> jc-1.4.0.tar.gz: java/nio/channels/FileChannel__24MapMode.h <==
// public class java.nio.channels.FileChannel$MapMode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e2811ba56861a7c0 java_nio_channels_FileChannel__24MapMode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_FileChannel__24MapMode_H_
#define _JC_java_nio_channels_FileChannel__24MapMode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_channels_FileChannel__24MapMode$object;

// Typedefs
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$sub_refs	_jc_java_nio_channels_FileChannel__24MapMode$sub_refs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs	_jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$refs	_jc_java_nio_channels_FileChannel__24MapMode$refs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$nonrefs	_jc_java_nio_channels_FileChannel__24MapMode$nonrefs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$object	_jc_java_nio_channels_FileChannel__24MapMode$object;

typedef struct _jc_java_nio_channels_FileChannel__24MapMode$fields_struct	_jc_java_nio_channels_FileChannel__24MapMode$fields_struct;
typedef const struct _jc_java_nio_channels_FileChannel__24MapMode$vmethods	_jc_java_nio_channels_FileChannel__24MapMode$vmethods;
typedef const struct _jc_java_nio_channels_FileChannel__24MapMode$vtable	_jc_java_nio_channels_FileChannel__24MapMode$vtable;
typedef const struct _jc_java_nio_channels_FileChannel__24MapMode$vtype	_jc_java_nio_channels_FileChannel__24MapMode$vtype;

// Class fields structure
struct _jc_java_nio_channels_FileChannel__24MapMode$fields_struct {
	struct _jc_java_nio_channels_FileChannel__24MapMode$object	*PRIVATE;
	struct _jc_java_nio_channels_FileChannel__24MapMode$object	*READ__5fONLY;
	struct _jc_java_nio_channels_FileChannel__24MapMode$object	*READ__5fWRITE;
};
extern _jc_java_nio_channels_FileChannel__24MapMode$fields_struct _jc_java_nio_channels_FileChannel__24MapMode$class_fields;

// Constructors
extern void _jc_java_nio_channels_FileChannel__24MapMode$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_channels_FileChannel__24MapMode$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_channels_FileChannel__24MapMode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_nio_channels_FileChannel__24MapMode$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_FileChannel__24MapMode$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_nio_channels_FileChannel__24MapMode$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_nio_channels_FileChannel__24MapMode$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_nio_channels_FileChannel__24MapMode$object *);
};

// Vtable
struct _jc_java_nio_channels_FileChannel__24MapMode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_FileChannel__24MapMode$vmethods	java_nio_channels_FileChannel__24MapMode;
};

// Vtype
struct _jc_java_nio_channels_FileChannel__24MapMode$vtype {
	_jc_type			type;
	_jc_java_nio_channels_FileChannel__24MapMode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_FileChannel__24MapMode$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_FileChannel__24MapMode$refs {
    _jc_java_nio_channels_FileChannel__24MapMode$sub_refs	java_nio_channels_FileChannel__24MapMode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs {
	jint	m;
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_FileChannel__24MapMode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs	java_nio_channels_FileChannel__24MapMode;
};

// Object instance structure
struct _jc_java_nio_channels_FileChannel__24MapMode$object {
	_jc_java_nio_channels_FileChannel__24MapMode$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_FileChannel__24MapMode$vtype	*vtype;
	_jc_java_nio_channels_FileChannel__24MapMode$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_FileChannel__24MapMode$vtype _jc_java_nio_channels_FileChannel__24MapMode$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_FileChannel__24MapMode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_FileChannel__24MapMode$class_object;

#endif	/* _JC_java_nio_channels_FileChannel__24MapMode_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/FileChannel__24MapMode.h <==
// public class java.nio.channels.FileChannel$MapMode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e2811ba56861a7c0 java_nio_channels_FileChannel__24MapMode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_FileChannel__24MapMode_H_
#define _JC_java_nio_channels_FileChannel__24MapMode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_channels_FileChannel__24MapMode$object;

// Typedefs
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$sub_refs	_jc_java_nio_channels_FileChannel__24MapMode$sub_refs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs	_jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$refs	_jc_java_nio_channels_FileChannel__24MapMode$refs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$nonrefs	_jc_java_nio_channels_FileChannel__24MapMode$nonrefs;
typedef struct _jc_java_nio_channels_FileChannel__24MapMode$object	_jc_java_nio_channels_FileChannel__24MapMode$object;

typedef struct _jc_java_nio_channels_FileChannel__24MapMode$fields_struct	_jc_java_nio_channels_FileChannel__24MapMode$fields_struct;
typedef const struct _jc_java_nio_channels_FileChannel__24MapMode$vmethods	_jc_java_nio_channels_FileChannel__24MapMode$vmethods;
typedef const struct _jc_java_nio_channels_FileChannel__24MapMode$vtable	_jc_java_nio_channels_FileChannel__24MapMode$vtable;
typedef const struct _jc_java_nio_channels_FileChannel__24MapMode$vtype	_jc_java_nio_channels_FileChannel__24MapMode$vtype;

// Class fields structure
struct _jc_java_nio_channels_FileChannel__24MapMode$fields_struct {
	struct _jc_java_nio_channels_FileChannel__24MapMode$object	*PRIVATE;
	struct _jc_java_nio_channels_FileChannel__24MapMode$object	*READ__5fONLY;
	struct _jc_java_nio_channels_FileChannel__24MapMode$object	*READ__5fWRITE;
};
extern _jc_java_nio_channels_FileChannel__24MapMode$fields_struct _jc_java_nio_channels_FileChannel__24MapMode$class_fields;

// Constructors
extern void _jc_java_nio_channels_FileChannel__24MapMode$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_channels_FileChannel__24MapMode$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_channels_FileChannel__24MapMode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_nio_channels_FileChannel__24MapMode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_FileChannel__24MapMode$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_nio_channels_FileChannel__24MapMode$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_FileChannel__24MapMode$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_nio_channels_FileChannel__24MapMode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_FileChannel__24MapMode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_FileChannel__24MapMode$vmethods	java_nio_channels_FileChannel__24MapMode;
};

// Vtype
struct _jc_java_nio_channels_FileChannel__24MapMode$vtype {
	_jc_type			type;
	_jc_java_nio_channels_FileChannel__24MapMode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_FileChannel__24MapMode$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_FileChannel__24MapMode$refs {
    _jc_java_nio_channels_FileChannel__24MapMode$sub_refs	java_nio_channels_FileChannel__24MapMode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs {
	jint	m;
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_FileChannel__24MapMode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_FileChannel__24MapMode$sub_nonrefs	java_nio_channels_FileChannel__24MapMode;
};

// Object instance structure
struct _jc_java_nio_channels_FileChannel__24MapMode$object {
	_jc_java_nio_channels_FileChannel__24MapMode$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_FileChannel__24MapMode$vtype	*vtype;
	_jc_java_nio_channels_FileChannel__24MapMode$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_FileChannel__24MapMode$vtype _jc_java_nio_channels_FileChannel__24MapMode$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_FileChannel__24MapMode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_FileChannel__24MapMode$class_object;

#endif	/* _JC_java_nio_channels_FileChannel__24MapMode_H_ */
